dfvue: A minimal GUI for a quick view of csv files.

Created Jul 2023- by Matthias Cuntz.

It is distributed under the MIT License (see LICENSE file and below).

Copyright (c) 2023- Matthias Cuntz

Authors
-------

* `Matthias Cuntz`_, E-mail: mc (at) macu (dot) de

.. _Matthias Cuntz: https://github.com/mcuntz
